//******************************************************************************
// AUTEUR : Frederic Maleval & Jean-Pierre Planas
// DESCRIPTION : FRAMEWORK de test de monte en charge
//******************************************************************************
unit MC_ThreadClt;

interface

uses
  Classes,windows,ActiveX, SysUtils;

type
  TErreur = (etNoError, etResultsDiffers, etException);
  TThreadClient= class;  // declaration forward
  TThreadClientClass=class of TThreadClient;  // Meta Classe

  TThreadClient =class(TThread)
  private
    FResultatAttendu : string;
    FResultatRecu    : string;
    FErreur: TErreur;
    FStop: Boolean;
    FTempsTotal: DWORD;
    FTempsExec: DWORD;
  public
    IndexThread     : Integer;  // N du thread
    Tag             : Longint;

    procedure Execute; override;
    function Check_Result(Index:integer;var pResultatAttendu, pResultatRecu:string):boolean;virtual;abstract;
    constructor create(S:Boolean);

    class function  GetTempsDebut : DWORD;
    class procedure SetTempsDebut(Value : DWORD);
    class function  GetThreadClientClass : TThreadClientClass;
    class procedure SetThreadClientClass(Value : TThreadClientClass);

    property TempsTotal      : DWORD   read FTempsTotal     ;
    property TempsExec       : DWORD   read FTempsExec      ;
    property Stop            : Boolean read FStop ;  // Pour savoir si le thread a finit son boulot
    property Erreur          : TErreur read FErreur         ;
    property ResultatAttendu : string  read FResultatAttendu;
    property ResultatRecu    : string  read FResultatRecu   ;
    // Property statiques
    property TempsDebut      : DWORD   read GetTempsDebut write SetTempsDebut;
    property ThreadClientClass :TThreadClientClass read GetThreadClientClass write SetThreadClientClass;
  end;

implementation

uses mc_main;

{ TThreadClient }

// Attributs statiques de la classe TThreadClient.
// Comme Delphi 6 ne permet de faire des attributs statiques, on est oblig de faire des
// variables globales.
// Mais pour limiter leur impact, elles sont locale  l'unit car sous implementation.

var  FTempsDebut:DWORD; // var globale qui contient "l'heure" de dpart du test
     FThreadClientClass:TThreadClientClass; // var globale pour savoir quelle est
                                           // la classe  instancier

constructor TThreadClient.create(S: Boolean);
begin
  inherited;
  FStop := False;
  Tag := 0;
  FErreur := etNoError;
  FResultatAttendu  := 'Non inititialis';
  FResultatRecu     := 'Non inititialis';
end;

procedure TThreadClient.Execute;
var resAttendu,resRecu:string;
    tempsAvant:DWORD;
begin
  CoInitialize(nil);  // Le thread rentre dans un appartement STA au cas ou il s'agit de tester un objet COM
  try
    FStop := False;
    TempsAvant := gettickcount;
    // Debut du "calcul"
    try
      case Check_Result(IndexThread,resAttendu,resRecu) of
        true  :       FErreur:=etNoError;
        false :       FErreur:=etResultsDiffers;
      end;
      FResultatAttendu := resAttendu ;
      FResultatRecu    := resRecu    ;
    except
      on e:Exception do
        begin
        FErreur:=etException;
        FResultatRecu:=e.Message;
        end;
    end;
    // Fin du "calcul"
    FTempsTotal := gettickcount - TempsDebut;
    FTempsExec  := gettickcount - TempsAvant;
  finally
    CoUninitialize;
    FStop := True;
  end;
end;

class function TThreadClient.GetTempsDebut : DWORD;
begin
  Result:=FTempsDebut;
end;

class procedure TThreadClient.SetTempsDebut(Value : DWORD);
begin
  FTempsDebut:=Value;
end;

class function TThreadClient.GetThreadClientClass : TThreadClientClass;
begin
  Result:=FThreadClientClass;
end;

class procedure TThreadClient.SetThreadClientClass(Value : TThreadClientClass);
begin
  FThreadClientClass:=Value;
end;

end.

