unit UStrUtils;

interface

uses Sysutils;

function BTST (W:Word; B:Byte):Boolean;           {*Test a Bit 'B'*}
function Str_Replace(S,Sub,Rep:String;Mode:Word):String;
function DoubleChar(s:string;c:char):string;
function FileToStrPascal(FileName:string):string;
procedure WriteStrToFile(FileName:string;tab:array of string);
procedure MakeFilesToConstString(FileName:string);

implementation

{+---------------------------------------------------------------------------+
                               FUNCTION BTST                                
 ---------------------------------------------------------------------------
  IN.....: W (WORD) = Word Register to manage bits.                         
           B (BYTE) = Bit number to operate (0 to 15).                      
  OUT....: (BOOLEAN) = Bit set if TRUE else FALSE.                          
  NB.....: ASM68000 function (Origin).                                      
  EXPLAIN: Test the bit "B" of the "W" variable.                            
  SEEALSO: BCLR, BCHG, BSET                                                 
 +---------------------------------------------------------------------------+}

Function BTST (W:Word; B:Byte):Boolean;           {*Test a Bit 'B'*}
Begin
If (W And (1 shl B))=(1 shl B) Then BTST:=True Else BTST:=False;
End;

{+---------------------------------------------------------------------------+
                            FUNCTION STR_REPLACE                            
 ---------------------------------------------------------------------------
  IN.....: S (STRING) = Source string.                                      
           Sub (STRING) = Substring of S witch the function must replace    
           Rep (STRING) = String witch contain the replacement of Sub       
           Mode (WORD) =                                                    
            Bit  Num                                                        
             0   0001  Replace is case sensitive.                           
             1   0002                                                       
  OUT....: (STRING) = String result.                                        
  EXPLAIN: This function replace a substring in the source string by the    
           rep string.                                                      
  EXAMPLE: Str_Replace('%1 toto %1','%1','t')  =  't toto t'                
 +---------------------------------------------------------------------------+}
Function Str_Replace(S,Sub,Rep:String;Mode:Word):String;
Var P:Word;
Begin
If BTST(Mode,0) Then P:=Pos(Sub,S) Else P:=Pos(UpperCase(Sub),UpperCase(S));

If P=0 Then
  Begin
  Str_Replace:=S;
  Exit;
  End;
Str_Replace:=Copy(S,1,P-1)+Rep
             +Str_Replace(Copy(S,P+Length(Sub),Length(S)),Sub,Rep,Mode);
End;
//******************************************************************************
//                     DoubleChar
//******************************************************************************
// IN.....: s (STRING) = chaine de caractre
//          c (CHAR)  = caractre  doubler
// OUT....: Result (STRING)  = chaine avec tous les carac
// EXPLAIN: Double tous les caractres contenus dans le paramtre c.
//******************************************************************************
function DoubleChar(s:string;c:char):string;
var i:integer;
begin
result:='';
for i:=1 to length(s) do
  if s[i]=c then Result:=Result+s[i]+s[i] else Result:=Result+s[i];
end;

//******************************************************************************
//                     FileToStrPascal
//******************************************************************************
// IN.....: FileName (STRING) = Nom du fichier  charger en mmoire
// OUT....: Result (STRING) = contenu du fichier avec les caractre ' doubls et
//          chaque ligne est encadr par des '
// EXPLAIN: Charge 1 fichier en mmoire dans un string
//******************************************************************************
function FileToStrPascal(FileName:string):string;
var f:TextFile;
    s:string;
begin
Result:='';
assignfile(f,FileName);
reset(f);
while not eof(f) do
  begin
  readln(f,s);
  Result:=Result+''''+DoubleChar(s,'''')+''''+#13#10;
  if not eof(f) then Result:=Result+'      +#13#10+';
  end;
closefile(f);
end;

//******************************************************************************
//                     WriteStrToFile
//******************************************************************************
// IN.....: FileName (STRING) = Nom du fichier  crire
//          tab (ARRAY OF STRING) = tableau de chaine de caractre  crire
// OUT....: /
// EXPLAIN: Stoke un tableau de chaine de caractre dans un fichier texte
//******************************************************************************
procedure WriteStrToFile(FileName:string;tab:array of string);
var i:integer;
    f:TextFile;
begin
assignfile(f,FileName);
rewrite(f);
for i:=0 to length(tab)-1 do write(f,tab[i]);
closefile(f);
end;

//******************************************************************************
//                     MakeFileToConstString
//******************************************************************************
// IN.....: FileName (STRING) = Nom du fichier  crire
// OUT....: /
// EXPLAIN: Prend tous les paramtres de la ligne de commande (liste de fichier)
//          et cre 1 fichier de sortie qui contient des constante pouvant tre
//          incluse dans un source pascal
//******************************************************************************
procedure MakeFilesToConstString(FileName:string);
var i:integer;
    tab:array of string;

function ConvertPointTo_(s:string):string;
begin
Result:=Str_Replace(s,'.','_',0);
end;

begin
  SetLength(tab,0);
  for i:=2 to ParamCount do
    begin
    SetLength(tab,Length(tab)+1);
    tab[i-2]:='const '+ConvertPointTo_(ExtractFileName(ParamStr(i)))+' = '+FileToStrPascal(ParamStr(i))+' ;'+#13#10;
    end;
  WriteStrToFile(FileName,tab);
  SetLength(tab,0);
end;

end.
